summary refs log tree commit diff
path: root/pkgs/development
diff options
context:
space:
mode:
authorThomas Tuegel <ttuegel@gmail.com>2014-09-21 16:34:35 -0500
committerThomas Tuegel <ttuegel@gmail.com>2014-09-21 16:34:35 -0500
commita77fa69cb8207c41607b8506023b5c756bb640ab (patch)
treec254e3f972f2d9abf0697fc1bf9540c8bc6b6300 /pkgs/development
parent50352beb31b474693f373f18a78158ae771d035f (diff)
parent16901dcae2934c887c18ec018af1df53e9288666 (diff)
downloadnixlib-a77fa69cb8207c41607b8506023b5c756bb640ab.tar
nixlib-a77fa69cb8207c41607b8506023b5c756bb640ab.tar.gz
nixlib-a77fa69cb8207c41607b8506023b5c756bb640ab.tar.bz2
nixlib-a77fa69cb8207c41607b8506023b5c756bb640ab.tar.lz
nixlib-a77fa69cb8207c41607b8506023b5c756bb640ab.tar.xz
nixlib-a77fa69cb8207c41607b8506023b5c756bb640ab.tar.zst
nixlib-a77fa69cb8207c41607b8506023b5c756bb640ab.zip
atlas: maintenance
Diffstat (limited to 'pkgs/development')
-rw-r--r--pkgs/development/libraries/science/math/atlas/default.nix15
1 files changed, 11 insertions, 4 deletions
diff --git a/pkgs/development/libraries/science/math/atlas/default.nix b/pkgs/development/libraries/science/math/atlas/default.nix
index 9aab09094a0c..938778734e09 100644
--- a/pkgs/development/libraries/science/math/atlas/default.nix
+++ b/pkgs/development/libraries/science/math/atlas/default.nix
@@ -1,5 +1,5 @@
 { stdenv, fetchurl, gfortran, tolerateCpuTimingInaccuracy ? true, shared ? false
-, cpuConfig ? if stdenv.isi686 then "-b 32 -A 18 -V 1" else "-b 64 -A 31 -V 192"
+, cpuConfig ? if stdenv.isi686 then "-b 32 -A 18 -V 1" else "-b 64 -A 31 -V 384"
 }:
 
 # Atlas detects the CPU and optimizes its build accordingly. This is great when
@@ -15,13 +15,18 @@
 #   |---------------------------------------------+------------------------|
 #   | -b 32                                       | -b 64                  |
 #   | -A 18  (Pentium II)                         | -A 31 (Athlon K7)      |
 #   | -V 1 (No SIMD: Pentium II doesn't have SSE) | -V 192 (SSE1 and SSE2) |
 #
 # Users who want to compile a highly optimized version of ATLAS that's suitable
 # for their local machine can override these settings accordingly.
+#
+# The -V flags can change with each release as new instruction sets are added
+# because upstream thinks it's a good idea to add entries at the start of an
+# enum, rather than the end. If the build suddenly fails with messages about
+# missing instruction sets, you may need to poke around in the source a bit.
 
 let
-  version = "3.10.1";
+  version = "3.10.2";
 
   optionalString = stdenv.lib.optionalString;
   optional = stdenv.lib.optional;
@@ -32,7 +37,7 @@ stdenv.mkDerivation {
 
   src = fetchurl {
     url = "mirror://sourceforge/math-atlas/atlas${version}.tar.bz2";
-    sha256 = "11ncgdc7kzb2y2gqb3sgarm5saj9fr07r3h2yh2h5bja429b85d2";
+    sha256 = "0bqh4bdnjdyww4mcpg6kn0x7338mfqbdgysn97dzrwwb26di7ars";
   };
 
   buildInputs = [ gfortran ];
@@ -67,5 +72,7 @@ stdenv.mkDerivation {
       portable performance. At present, it provides C and Fortran77 interfaces to a
       portably efficient BLAS implementation, as well as a few routines from LAPACK.
     '';
+
+    maintainers = with stdenv.lib.maintainers; [ ttuegel ];
   };
 }
@@ -15,13 +15,18 @@
 #   | -b 32                                       | -b 64                  |
 #   | -A 18  (Pentium II)                         | -A 31 (Athlon K7)      |
-#   | -V 1 (No SIMD: Pentium II doesn't have SSE) | -V 192 (SSE1 and SSE2) |
+#   | -V 1 (No SIMD: Pentium II doesn't have SSE) | -V 384 (SSE1 and SSE2) |
 #
 # Users who want to compile a highly optimized version of ATLAS that's suitable